@@ -12,34 +12,43 @@ It is responsible for creating the top-level C</tags/> hierarchy.
 
 =cut
 
-=head1 AUTHOR
+=head1 METHODS
 
-Steve Kemp <steve@steve.org.uk>
+Now follows documentation on the available methods.
 
 =cut
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
-
-
 package Chronicle::Plugin::Generate::Tags;
 
 use strict;
 use warnings;
 
 
-=begin doc
+=head2 on_generate
 
-This method is called when all the parsing is done, and we use this
-to generate the tag-output pages.
+The C<on_generate> method is automatically invoked to generate output
+pages.  This particular plugin method is invoked I<after> any
+C<on_initiate> methods which might be present.
 
-=end doc
+This method is responsible for generating the tag-output, which
+includes two sets of pages:
+
+=over 8
+
+=item C</tags/index.html>
+
+This is created using the C<tag_index.tmpl> theme-template, and contains
+a list of all the tags which have ever been used.
+
+=item C</tags/$tag/index.html>
+
+This is created for each distinct tag, from the theme-template
+C<tag.tmpl>
+
+=back
+
+If either template is missing then this plugin will skip that part of
+the generation.
 
 =cut
 
@@ -51,22 +60,20 @@ sub on_generate
     my $config = $args{ 'config' };
 
 
-    outputTags( $config, $dbh );
+    _outputTags( $config, $dbh );
 
-    outputTagCloud( $config, $dbh );
+    _outputTagCloud( $config, $dbh );
 }
 
 
-=begin doc
+=head2 _outputTags
 
 Output a page (`output/tags/$tag/index.html`) for each distinct tag
 we've ever used.
 
-=end doc
-
 =cut
 
-sub outputTags
+sub _outputTags
 {
     my ( $config, $dbh ) = (@_);
 
@@ -82,6 +89,7 @@ sub outputTags
     $all->bind_columns( undef, \$tag );
 
     my $c = Chronicle::load_template("tag.tmpl");
+    return unless ($c);
 
     while ( $all->fetch() )
     {
@@ -139,16 +147,14 @@ sub outputTags
 
 
 
-=begin doc
+=head2 _outputTagCloud
 
 Output `output/tags/index.html` containing a complete tag-cloud of the
 tags we've ever used.
 
-=end doc
-
 =cut
 
-sub outputTagCloud
+sub _outputTagCloud
 {
     my ( $config, $dbh ) = (@_);
 
@@ -195,6 +201,8 @@ sub outputTagCloud
 
 
     my $c = Chronicle::load_template("tag_index.tmpl");
+    return unless ($c);
+
     $c->param( all_tags => $tags ) if ($tags);
     $c->param( top => $config->{ 'top' } );
     open( my $handle, ">", "$config->{'output'}/tags/index.html" ) or
